@@ -1544,6 +1544,34 @@ char *TranslateString(char *Strng,SMS_PProvider Pv)
             }
           }
         }
+#if 0
+        else if(strncasecmp(S,"RTIf-",5) == 0)
+        {
+          q = strchr(S+5,'-'); // RTIf-ParamName-ParamValue
+          if(q != NULL)
+          {
+            q[0] = 0;q++;
+            //if(S != NULL) /* useless */
+            {
+              for(i=0;i<Pv->NbParams;i++)
+              {
+                if(strcasecmp(S+5,Pv->Params[i].Name) == 0)
+                {
+                  found = 0;
+                  if(strlen(Pv->Params[i].Value) > 0)
+                  {
+                    SU_strcpy(buf,q,sizeof(buf));
+                    str = buf;
+                  }
+                  else
+                    str = "";
+                  break;
+                }
+              }
+            }
+          }
+        }
+#endif /* 0 */
         else
         {
           char *dum = strchr(S,'-'); /* Search for sub-string */
@@ -1896,7 +1924,7 @@ void PrintProviderHelp(const char ProviderName[],SMS_PProvider Pv)
 {
   int i;
 
-  printf("SmsSend version %s - Copyright(c) Ze KiLleR / SkyTech - 2000'03\n",SMSSEND_VERSION);
+  printf("SmsSend version %s - Copyright(c) Ze KiLleR / SkyTech - 2000'04\n",SMSSEND_VERSION);
   printf("Arguments for provider %s :\n",ProviderName);
   for(i=0;i<Pv->NbParams;i++)
   {
@@ -1914,7 +1942,7 @@ void PrintProviderHelp(const char ProviderName[],SMS_PProvider Pv)
 
 void PrintHelp(char *Msg,bool version)
 {
-  printf("SmsSend version %s - Copyright(c) Ze KiLleR / SkyTech - 2000'03\n",SMSSEND_VERSION);
+  printf("SmsSend version %s - Copyright(c) Ze KiLleR / SkyTech - 2000'04\n",SMSSEND_VERSION);
   if(version)
     return;
   printf("Usage : smssend [options] <provider> [arguments] -- [SkyUtils options]\n");
@@ -1991,7 +2019,7 @@ int main(int argc,char *argv[])
       {
         if(!SMS_Quiet)
         {
-          printf("SmsSend version %s - Copyright(c) Ze KiLleR / SkyTech - 2000'03\n",SMSSEND_VERSION);
+          printf("SmsSend version %s - Copyright(c) Ze KiLleR / SkyTech - 2000'04\n",SMSSEND_VERSION);
           printf("Trying to update SmsSend...\n");
         }
         CheckForUpdateSmsSend();
@@ -2010,7 +2038,10 @@ int main(int argc,char *argv[])
         return 0;
       }
       else if(strcasecmp(argv[i],"-q") == 0)
+      {
         SMS_Quiet = true;
+        j--;
+      }
       else
       {
         snprintf(Cmd,sizeof(Cmd),"Unknown option : %s",argv[i]);
@@ -2023,7 +2054,7 @@ int main(int argc,char *argv[])
       SU_PList Prof = GetProfile((const char *)&argv[i][1]);
       if(Prof == NULL)
       {
-        printf("SmsSend version %s - Copyright(c) Ze KiLleR / SkyTech - 2000'03\n",SMSSEND_VERSION);
+        printf("SmsSend version %s - Copyright(c) Ze KiLleR / SkyTech - 2000'04\n",SMSSEND_VERSION);
         printf("Unknown profile '%s'\n",(char *)&argv[i][1]);
         return -3;
       }
@@ -2058,7 +2089,7 @@ int main(int argc,char *argv[])
   {
     if(!SMS_Quiet)
     {
-      printf("SmsSend version %s - Copyright(c) Ze KiLleR / SkyTech - 2000'03\n",SMSSEND_VERSION);
+      printf("SmsSend version %s - Copyright(c) Ze KiLleR / SkyTech - 2000'04\n",SMSSEND_VERSION);
       printf("Trying to install %s script...\n",PvName);
     }
     InstallScript(PvName);
@@ -2108,7 +2139,7 @@ int main(int argc,char *argv[])
   {
     if(!SMS_Quiet)
     {
-      printf("SmsSend version %s - Copyright(c) Ze KiLleR / SkyTech - 2000'03\n",SMSSEND_VERSION);
+      printf("SmsSend version %s - Copyright(c) Ze KiLleR / SkyTech - 2000'04\n",SMSSEND_VERSION);
       printf("Trying to update %s script...\n",Nargv[pvPos]);
     }
     CheckForUpdate(PvName);
